Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .binary_config import BinaryConfig, BinaryField

9 from .cls import TypedConfig, TypedMapping, TypedMutableMapping, update

10 from .core import (

11 check_and_convert_data,

12 convert_config,

13 ensure_types,

14 load_data,

15 load_into,

16 load_into_class,

17 load_into_instance,

18)

19 from .dump import asbytes, asdict, asjson, astoml, asyaml

20 from .helpers import all_annotations, check_type

21 from .loaders import register_loader as loader

22 from .postpone import postpone

23 from .singleton import Singleton, SingletonMeta

24 from .type_converters import register_converter as converter

25

26 __all__ = [

27 # binary

28 "BinaryConfig",

29 "BinaryField",

30 # cls

31 "TypedConfig",

32 "TypedMapping",

33 "TypedMutableMapping",

34 "update",

35 # singleton

36 "Singleton",

37 "SingletonMeta",

38 # core

39 "check_and_convert_data",

40 "convert_config",

41 "ensure_types",

42 "load_data",

43 "load_into",

44 "load_into_class",

45 "load_into_instance",

46 # helpers

47 "all_annotations",

48 "check_type",

49 # postpone

50 "postpone",

51 # dump

52 "asbytes",

53 "asdict",

54 "astoml",

55 "asyaml",

56 "asjson",

57 # register

58 "loader",

59 "converter",

60]